use std::io::{self, Write};

pub struct InfoTable {
    rows: Vec<(String, String)>,
    title: String,
}

impl InfoTable {
    pub fn with_title<T>(title: T) -> Self
    where
        T: ToString,
    {
        let title = title.to_string();

        Self {
            rows: Vec::new(),
            title,
        }
    }

    pub fn row(&mut self, key: impl ToString, value: impl ToString) -> &mut Self {
        self.rows.push((key.to_string(), value.to_string()));

        self
    }

    pub fn write_to(&self, mut writer: impl Write, width: usize) -> io::Result<()> {
        writeln!(writer, "━{:━<width$}", &self.title, width = width - 1)?;

        for &(ref key, ref val) in &self.rows {
            writeln!(writer, "{}: {}", key, val)?;
        }

        writer.write_all("━".repeat(width).as_bytes())?;
        writer.write_all(b"\n")?;

        Ok(())
    }
}
